expired property
TestFlight builds expire after 90 days. An expired build is still listed and can no longer be given to a group.
Implementation
final bool expired;
TestFlight builds expire after 90 days. An expired build is still listed and can no longer be given to a group.
final bool expired;