newestBuildNumber property
The highest build number Apple holds, whatever state it is in.
Not the newest usable one: a build uploaded four minutes ago is the newest and cannot be released.
Implementation
final String? newestBuildNumber;
The highest build number Apple holds, whatever state it is in.
Not the newest usable one: a build uploaded four minutes ago is the newest and cannot be released.
final String? newestBuildNumber;