schema property
This kind's schema number. Refuse one you do not recognize rather than reading optimistically — see docs/design/json-output.md.
Implementation
final int schema;
This kind's schema number. Refuse one you do not recognize rather than reading optimistically — see docs/design/json-output.md.
final int schema;