versionName property

String? versionName
final

The version the listing was compared against, or null when the tree declares nothing Apple scopes to a version.

Implementation

final String? versionName;