versions property

List<AppStoreVersionEntry> versions
final

In the order Apple returned them, which is newest first in practice and is not promised by the API.

Implementation

final List<AppStoreVersionEntry> versions;