BetaGroupEntry class

One TestFlight group a build is attached to.

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

BetaGroupEntry({required String name, required BetaGroupKindEntry kind})
const
BetaGroupEntry.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
kind BetaGroupKindEntry
Internal, external, or that Apple did not say. See BetaGroupKindEntry.
final
name String
Apple's name for the group, or (unnamed) when it carried none.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited