name property
The release name, which Play generates from the version name when it was not set, or null when the response did not carry one.
Implementation
final String? name;
The release name, which Play generates from the version name when it was not set, or null when the response did not carry one.
final String? name;