result property
What the run did. Present on UploadEvent.result, which is the last line of a run that finished.
Implementation
final PlayUploadResult? result;
What the run did. Present on UploadEvent.result, which is the last line of a run that finished.
final PlayUploadResult? result;