appId property
String
get
appId
App Store Connect's own id for the app, as appstore prints it.
Implementation
String get appId => _app.id;
App Store Connect's own id for the app, as appstore prints it.
String get appId => _app.id;