terminal property
bool
get
terminal
Whether this poll ended the wait, one way or the other.
Implementation
bool get terminal =>
state == 'VALID' || state == 'FAILED' || state == 'INVALID';
Whether this poll ended the wait, one way or the other.
bool get terminal =>
state == 'VALID' || state == 'FAILED' || state == 'INVALID';