visible property
bool
get
visible
Whether App Store Connect has the build at all yet.
Implementation
bool get visible => state != null;
Whether App Store Connect has the build at all yet.
bool get visible => state != null;