where property
What was being checked, in terms a reader can go and look at — a version heading and a platform, or a locale and a screenshot directory.
Implementation
final String where;
What was being checked, in terms a reader can go and look at — a version heading and a platform, or a locale and a screenshot directory.
final String where;