versionName property
The version the listing was compared against, or null when the tree declares nothing Apple scopes to a version.
Implementation
final String? versionName;
The version the listing was compared against, or null when the tree declares nothing Apple scopes to a version.
final String? versionName;