locale property
The appStoreVersionLocalizations locale this preview hangs off, such as
en-US. Two collections up from the preview itself, and the half of what
names it to a person.
Implementation
final String? locale;
The appStoreVersionLocalizations locale this preview hangs off, such as
en-US. Two collections up from the preview itself, and the half of what
names it to a person.
final String? locale;