lines property
The two lines cux_ship appstore versions prints for this version.
Implementation
List<String> get lines => <String>[
' $versionString $appStoreState $releaseType',
// Printed because it is required before review and null by default, and
// because a run that reports having written it is not evidence Apple
// kept it.
' copyright: ${copyright ?? "(unset)"}',
];