AppStoreVersions class
The App Store version records for one app on one platform.
Constructors
-
AppStoreVersions({required AscPlatform platform, required List<
AppStoreVersion> versions}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
lines
→ List<
String> -
Exactly what
cux_ship appstore versionsprints.no setter - platform → AscPlatform
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
versions
→ List<
AppStoreVersion> -
In the order Apple returned them, which is newest first in practice and
is not promised by the API.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
version(
String versionString) → AppStoreVersion? -
The version record for
versionString, or null.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited