versions property
In the order Apple returned them, which is newest first in practice and is not promised by the API.
Implementation
final List<AppStoreVersion> versions;
In the order Apple returned them, which is newest first in practice and is not promised by the API.
final List<AppStoreVersion> versions;